from setuptools import setup

setup(
    name='qsh',
    version='0.5.3',
    url='https://github.com/nethask/qsh',
    author='Artyom Knyazev',
    author_email='nethask@gmail.com',
    license='MIT',
    install_requires=['python-dateutil']
)
